====================
``searching`` module
====================

.. automodule:: whoosh.searching


Searching classes
=================

.. autoclass:: Searcher
    :members:


Results classes
===============

.. autoclass:: Results
    :members:

.. autoclass:: Hit
    :members:

.. autoclass:: ResultsPage
    :members:


Exceptions
==========

.. autoexception:: NoTermsException
.. autoexception:: TimeLimit

